@@ -17,7 +17,7 @@
 import javabridge
 import logging
 import numpy as np
-from weka.core.classes import JavaObject
+from weka.core.classes import JavaObject, Random
 import weka.core.typeconv as typeconv
 
 # logging setup
@@ -75,6 +75,23 @@ class Instances(JavaObject):
         """
         return self.num_instances
 
+    def __getitem__(self, subset):
+        """
+        Returns the specified row or subset.
+
+        :param subset: the index of the row to return or a subset (slice)
+        :type subset: int or slice
+        :return: the row or subset
+        :rtype: Instance or Instances
+        """
+        if isinstance(subset, slice):
+            result = Instances.template_instances(self)
+            for i in range(*subset.indices(len(self))):
+                result.add_instance(self.get_instance(i))
+        else:
+            result = self.get_instance(subset)
+        return result
+
     @property
     def relationname(self):
         """
@@ -558,6 +575,36 @@ class Instances(JavaObject):
         test_inst = Instances.copy_instances(data, train_size, test_size)
         return train_inst, test_inst
 
+    def cv_splits(self, folds=10, rnd=None, stratify=True):
+        """
+        Generates a list of train/test pairs used in cross-validation.
+        Creates a copy of the dataset beforehand when randomizing.
+
+        :param folds: the number of folds to use, >= 2
+        :type folds: int
+        :param rnd: the random number generator to use for randomization, skips randomization if None
+        :type rnd: Random
+        :param stratify: whether to stratify the data after randomization
+        :type stratify: bool
+        :return: the list of train/test split tuples
+        :rtype: list
+        """
+        result = []
+        if rnd is not None:
+            data = Instances.copy_instances(self)
+            data.randomize(rnd)
+            if stratify:
+                data.stratify(folds)
+        else:
+            data = self
+
+        for i in range(folds):
+            train = data.train_cv(folds, i, random=rnd)
+            test = data.test_cv(folds, i)
+            result.append((train, test))
+
+        return result
+
     @classmethod
     def summary(cls, inst):
         """
